package sun.util.locale.provider;

import java.util.Objects;
import java.util.Locale;
import java.util.Set;
import java.util.spi.TimeZoneNameProvider;

public class TimeZoneNameProviderImpl extends TimeZoneNameProvider
{
    private final LocaleProviderAdapter.Type type;
    private final Set<String> langtags;
    
    TimeZoneNameProviderImpl(LocaleProviderAdapter.Type type, Set<String> langtags) {
        this.type = type;
        this.langtags = langtags;
    }
    
    @Override
    public Locale[] getAvailableLocales() {
        return LocaleProviderAdapter.toLocaleArray(this.langtags);
    }
    
    @Override
    public boolean isSupportedLocale(Locale locale) {
        return LocaleProviderAdapter.isSupportedLocale(locale, this.type, this.langtags);
    }
    
    @Override
    public String getDisplayName(String s, boolean b, int n, Locale locale) {
        String[] displayNameArray = this.getDisplayNameArray(s, locale);
        if (Objects.nonNull(displayNameArray)) {
            assert displayNameArray.length >= 7;
            int n2 = b ? 3 : 1;
            if (n == 0) {
                ++n2;
            }
            return displayNameArray[n2];
        }
        else {
            return null;
        }
    }
    
    @Override
    public String getGenericDisplayName(String s, int n, Locale locale) {
        String[] displayNameArray = this.getDisplayNameArray(s, locale);
        if (Objects.nonNull(displayNameArray)) {
            assert displayNameArray.length >= 7;
            return displayNameArray[(n == 1) ? 5 : 6];
        }
        else {
            return null;
        }
    }
    
    private String[] getDisplayNameArray(String obj, Locale obj2) {
        Objects.requireNonNull(obj);
        Objects.requireNonNull(obj2);
        return LocaleProviderAdapter.forType(this.type).getLocaleResources(obj2).getTimeZoneNames(obj);
    }
    
    String[][] getZoneStrings(Locale locale) {
        return LocaleProviderAdapter.forType(this.type).getLocaleResources(locale).getZoneStrings();
    }
}
